import { ComponentPublicInstance, nextTick, App } from 'vue';
import { DOMWrapper } from './domWrapper';
import { FindAllComponentsSelector, FindComponentSelector } from './types';
import { TriggerOptions } from './createDomEvent';
export declare class VueWrapper<T extends ComponentPublicInstance> {
    private componentVM;
    private rootVM;
    private __app;
    private __setProps;
    constructor(app: App | null, vm: ComponentPublicInstance, setProps?: (props: Record<string, any>) => void);
    private get hasMultipleRoots();
    private get parentElement();
    get element(): Element;
    get vm(): T;
    props(): {
        [key: string]: any;
    };
    props(selector: string): any;
    classes(): string[];
    classes(className: string): boolean;
    attributes(): {
        [key: string]: string;
    };
    attributes(key: string): string;
    exists(): boolean;
    emitted<T = unknown>(): Record<string, T[]>;
    emitted<T = unknown>(eventName?: string): T[];
    html(): string;
    text(): string;
    find<K extends keyof HTMLElementTagNameMap>(selector: K): DOMWrapper<HTMLElementTagNameMap[K]>;
    find<K extends keyof SVGElementTagNameMap>(selector: K): DOMWrapper<SVGElementTagNameMap[K]>;
    find<T extends Element>(selector: string): DOMWrapper<T>;
    get<K extends keyof HTMLElementTagNameMap>(selector: K): Omit<DOMWrapper<HTMLElementTagNameMap[K]>, 'exists'>;
    get<K extends keyof SVGElementTagNameMap>(selector: K): Omit<DOMWrapper<SVGElementTagNameMap[K]>, 'exists'>;
    get<T extends Element>(selector: string): Omit<DOMWrapper<T>, 'exists'>;
    findComponent<T extends ComponentPublicInstance>(selector: new () => T): VueWrapper<T>;
    findComponent<T extends ComponentPublicInstance>(selector: FindComponentSelector): VueWrapper<T>;
    getComponent<T extends ComponentPublicInstance>(selector: new () => T): Omit<VueWrapper<T>, 'exists'>;
    getComponent<T extends ComponentPublicInstance>(selector: FindComponentSelector): Omit<VueWrapper<T>, 'exists'>;
    findAllComponents(selector: FindAllComponentsSelector): VueWrapper<T>[];
    findAll<K extends keyof HTMLElementTagNameMap>(selector: K): DOMWrapper<HTMLElementTagNameMap[K]>[];
    findAll<K extends keyof SVGElementTagNameMap>(selector: K): DOMWrapper<SVGElementTagNameMap[K]>[];
    findAll<T extends Element>(selector: string): DOMWrapper<T>[];
    setData(data: Record<string, any>): Promise<void>;
    setProps(props: Record<string, any>): Promise<void>;
    setValue(value: any, prop?: string): Promise<void>;
    trigger(eventString: string, options?: TriggerOptions): Promise<typeof nextTick>;
    unmount(): void;
}
export declare function createWrapper<T extends ComponentPublicInstance>(app: App | null, vm: ComponentPublicInstance, setProps?: (props: Record<string, any>) => void): VueWrapper<T>;
